==> qmmp-debuginfo-1.1.9-1.tar.xz: usr/src/debug/qmmp-1.1.9-1/src/plugins/Ui/qsui/qrc_qsui_txt.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.6.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qmmp/qmmp-1.1.9-1.x86_64/src/qmmp-1.1.9/src/plugins/Ui/qsui/txt/ascii_logo.txt
  0x0,0x0,0x0,0x78,
  0x0,
  0x0,0x2,0x23,0x78,0x9c,0x8d,0x50,0x41,0xe,0xc0,0x20,0x8,0xbb,0xf3,0xa,0x7f,
  0xc0,0x77,0x76,0x20,0xe9,0x47,0x78,0xfc,0x70,0x18,0x3,0xe8,0xdc,0x9a,0x90,0x90,
  0xb6,0x16,0x84,0x5a,0x85,0x58,0x31,0xf5,0xe,0x1,0xc6,0x83,0x33,0x65,0x1e,0xf0,
  0x15,0x60,0x8e,0xa7,0x12,0x45,0x2d,0x11,0x2f,0x10,0x6a,0xfa,0xc3,0xa6,0xd4,0xf7,
  0xf8,0x30,0xc1,0xb7,0x97,0xa3,0xc9,0x3d,0xa7,0xb0,0x11,0x63,0xd0,0xbd,0x9,0x4a,
  0xf3,0x68,0xbb,0xe5,0x83,0xbc,0x3b,0x81,0x84,0xd7,0xa8,0x13,0x10,0xc3,0x97,0xcf,
  0x70,0xd2,0x7c,0x38,0x3c,0x43,0x57,0x89,0xc7,0xfb,0x55,0xd2,0xd9,0x14,0xc9,0xc6,
  0xcf,0x86,0x6e,0xd7,0x67,0x97,0x33,
  
};

static const unsigned char qt_resource_name[] = {
  // ascii_logo.txt
  0x0,0xe,
  0x7,0x21,0xad,0xb4,
  0x0,0x61,
  0x0,0x73,0x0,0x63,0x0,0x69,0x0,0x69,0x0,0x5f,0x0,0x6c,0x0,0x6f,0x0,0x67,0x0,0x6f,0x0,0x2e,0x0,0x74,0x0,0x78,0x0,0x74,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/ascii_logo.txt
  0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qsui_txt)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qsui_txt)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qsui_txt)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qsui_txt)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qsui_txt)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qsui_txt)(); }
   } dummy;
}

==> qmmp-debuginfo-1.1.12-1.tar.xz: usr/src/debug/qmmp-1.1.12-1/src/plugins/Ui/qsui/qrc_qsui_txt.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qmmp/qmmp-1.1.12-1.i686/src/qmmp-1.1.12/src/plugins/Ui/qsui/txt/ascii_logo.txt
  0x0,0x0,0x0,0x78,
  0x0,
  0x0,0x2,0x23,0x78,0x9c,0x8d,0x50,0x41,0xe,0xc0,0x20,0x8,0xbb,0xf3,0xa,0x7f,
  0xc0,0x77,0x76,0x20,0xe9,0x47,0x78,0xfc,0x70,0x18,0x3,0xe8,0xdc,0x9a,0x90,0x90,
  0xb6,0x16,0x84,0x5a,0x85,0x58,0x31,0xf5,0xe,0x1,0xc6,0x83,0x33,0x65,0x1e,0xf0,
  0x15,0x60,0x8e,0xa7,0x12,0x45,0x2d,0x11,0x2f,0x10,0x6a,0xfa,0xc3,0xa6,0xd4,0xf7,
  0xf8,0x30,0xc1,0xb7,0x97,0xa3,0xc9,0x3d,0xa7,0xb0,0x11,0x63,0xd0,0xbd,0x9,0x4a,
  0xf3,0x68,0xbb,0xe5,0x83,0xbc,0x3b,0x81,0x84,0xd7,0xa8,0x13,0x10,0xc3,0x97,0xcf,
  0x70,0xd2,0x7c,0x38,0x3c,0x43,0x57,0x89,0xc7,0xfb,0x55,0xd2,0xd9,0x14,0xc9,0xc6,
  0xcf,0x86,0x6e,0xd7,0x67,0x97,0x33,
  
};

static const unsigned char qt_resource_name[] = {
  // ascii_logo.txt
  0x0,0xe,
  0x7,0x21,0xad,0xb4,
  0x0,0x61,
  0x0,0x73,0x0,0x63,0x0,0x69,0x0,0x69,0x0,0x5f,0x0,0x6c,0x0,0x6f,0x0,0x67,0x0,0x6f,0x0,0x2e,0x0,0x74,0x0,0x78,0x0,0x74,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/ascii_logo.txt
  0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x45,0x85,0xb,0x60,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qsui_txt)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qsui_txt)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qsui_txt)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qsui_txt)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qsui_txt)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qsui_txt)(); }
   } dummy;
}
